PALM-meteo: palmmeteo.plugins.SetupPluginMixin Class Reference

PALM-meteo

Public Member Functions | List of all members
palmmeteo.plugins.SetupPluginMixin Class Reference
Inheritance diagram for palmmeteo.plugins.SetupPluginMixin:
[legend]
Collaboration diagram for palmmeteo.plugins.SetupPluginMixin:
[legend]

## Public Member Functions
def | setup_model (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.Plugin
def | check_config (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.PluginMeta
def | __new__ (cls, name, bases, dct)

## Detailed Description

    Base class mixin for setup plugins.
    Registers 'setup_model' method as a handler for event 'setup_model'.

    Abstract methods required to be implemented by derived classes:
        setup_model

## Member Function Documentation

## ◆ setup_model()

def palmmeteo.plugins.SetupPluginMixin.setup_model | ( |  | self,
|  | * | args,
|  | ** | kwargs
| ) |  |

Reimplemented in palmmeteo_stdplugins.setup.SetupPlugin, and palmmeteo_stdplugins.setup_staticdriver.StaticDriverPlugin.

The documentation for this class was generated from the following file:

- palmmeteo/plugins.py